import { UNITS } from './const/unit.js';

type Unit = (typeof UNITS)[number];
type UnitName = Unit["name"];
type UnitAbbreviation = Unit["abbreviation"];
type UnitKey = UnitName | UnitAbbreviation;
type PartialBy<T, K extends keyof T> = Omit<T, K> & Partial<Pick<T, K>>;
type IngredientAmount = {
    value: number;
    unit: UnitKey;
};
type Ingredient<TConversionTableKey extends string> = {
    name: string;
    amount: IngredientAmount;
    conversion?: Record<TConversionTableKey, IngredientAmount | UnitKey>;
    notes?: string;
};
type GlobalRecipeConfig<TConversionTableKey extends string> = {
    units: TConversionTableKey[];
};
type Recipe<TConversionTableKey extends string> = GlobalRecipeConfig<TConversionTableKey> & {
    name: string;
    thumbnail?: string;
    ingredients: Ingredient<TConversionTableKey>[];
    servings: number;
    instructions: string[];
};
type recipeOmittableKeys = "servings";
type RecipeConfig<TConversionTableKey extends string> = PartialBy<Recipe<TConversionTableKey>, recipeOmittableKeys>;

export type { GlobalRecipeConfig, Ingredient, IngredientAmount, Recipe, RecipeConfig, Unit, UnitAbbreviation, UnitKey, UnitName };
